summary refs log tree commit diff
path: root/gnu
diff options
context:
space:
mode:
Diffstat (limited to 'gnu')
-rw-r--r--gnu/packages/admin.scm6
-rw-r--r--gnu/packages/base.scm5
-rw-r--r--gnu/packages/bash.scm8
-rw-r--r--gnu/packages/bootstrap.scm38
-rw-r--r--gnu/packages/commencement.scm1
-rw-r--r--gnu/packages/cross-base.scm5
-rw-r--r--gnu/packages/ed.scm4
-rw-r--r--gnu/packages/emacs.scm3
-rw-r--r--gnu/packages/fontutils.scm4
-rw-r--r--gnu/packages/gcc.scm12
-rw-r--r--gnu/packages/gettext.scm5
-rw-r--r--gnu/packages/gnome.scm4
-rw-r--r--gnu/packages/gnupg.scm4
-rw-r--r--gnu/packages/libidn.scm4
-rw-r--r--gnu/packages/libunistring.scm4
-rw-r--r--gnu/packages/linux.scm38
-rw-r--r--gnu/packages/make-bootstrap.scm4
-rw-r--r--gnu/packages/multiprecision.scm14
-rw-r--r--gnu/packages/patches/coreutils-dummy-man.patch21
-rw-r--r--gnu/packages/patches/gettext-msgunfmt.patch58
-rw-r--r--gnu/packages/pcre.scm3
-rw-r--r--gnu/packages/perl.scm10
-rw-r--r--gnu/packages/python.scm50
-rw-r--r--gnu/packages/qt.scm3
-rw-r--r--gnu/packages/ssh.scm7
-rw-r--r--gnu/packages/texinfo.scm28
-rw-r--r--gnu/packages/video.scm31
-rw-r--r--gnu/packages/xdisorg.scm7
28 files changed, 167 insertions, 214 deletions
diff --git a/gnu/packages/admin.scm b/gnu/packages/admin.scm
index 5b5659910c..99eb95b800 100644
--- a/gnu/packages/admin.scm
+++ b/gnu/packages/admin.scm
@@ -412,7 +412,11 @@ connection alive.")
                      (for-each patch-shebang
                                (find-files "bind-9.9.5-P1" ".*"))
                      (zero? (system* "tar" "cf" "bind.tar.gz"
-                                     "bind-9.9.5-P1"))))
+                                     "bind-9.9.5-P1"
+                                     ;; avoid non-determinism in the archive
+                                     "--mtime=@0"
+                                     "--owner=root:0"
+                                     "--group=root:0"))))
                  (alist-cons-after
                   'install 'post-install
                   (lambda* (#:key inputs outputs #:allow-other-keys)
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index 31331a1080..9a433ae5e4 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -238,15 +238,14 @@ used to apply commands with arbitrarily long arguments.")
 (define-public coreutils
   (package
    (name "coreutils")
-   (version "8.23")
+   (version "8.24")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/coreutils/coreutils-"
                                 version ".tar.xz"))
             (sha256
              (base32
-              "0bdq6yggyl7nkc2pbl6pxhhyx15nyqhz3ds6rfn448n6rxdwlhzc"))
-            (patches (list (search-patch "coreutils-dummy-man.patch")))))
+              "0w11jw3fb5sslf0f72kxy7llxgk1ia3a6bcw0c9kmvxrlj355mx2"))))
    (build-system gnu-build-system)
    (inputs `(("acl"  ,acl)                        ; TODO: add SELinux
              ("gmp"  ,gmp)))
diff --git a/gnu/packages/bash.scm b/gnu/packages/bash.scm
index 45676f568b..6b2d0b855d 100644
--- a/gnu/packages/bash.scm
+++ b/gnu/packages/bash.scm
@@ -86,7 +86,13 @@
    (30 "0nrqb0m7s89qsrbfaffpilc5gcf82bx9yvgzld4hr79p5y54yhw5") ;CVE-2014-6278
    (31 "07d62bl3z7qa8v6kgk47vzzazw563mlk9zhrsr4xsbqgvmcrylnd")
    (32 "0jjgapfq4qhmndfrw8c3q3lva8xjdhlbd9cc631v41b0kb95g4w8")
-   (33 "05ma5rlxiadnfh925p4y7s0vvk917kmsdb1mfdx05gizl63pfapv")))
+   (33 "05ma5rlxiadnfh925p4y7s0vvk917kmsdb1mfdx05gizl63pfapv")
+   (34 "12gq9whkq3naa3iy7c7x5pfpvrg7d0kwqld8609zxphhy424ysgi")
+   (35 "1qy1jflmbazjykq766gwabkaiswnx7pwa66whqiny0w02zjqa39p")
+   (36 "0z6jbyy70lfdm6d3x0sbazbqdxb3xnpn9bmz7madpvrnbd284pxc")
+   (37 "04sqr8zkl6s5fccfvb775ppn3ldij5imria9swc39aq0fkfp1w9k")
+   (38 "0rv3g14mpgv8br267bf7rmgqlgwnc4v6g3g8y0sjba571i8amgmd")
+   (39 "1v3l3vkc3g2b6fjycqwlakr8xhiw6bmw6q0zd6bi0m0m4bnxr55b")))
 (define (download-patches store count)
   "Download COUNT Bash patches into store.  Return a list of
 number/base32-hash tuples, directly usable in the 'patch-series' form."
diff --git a/gnu/packages/bootstrap.scm b/gnu/packages/bootstrap.scm
index 1f0fe16688..f3c1c5a617 100644
--- a/gnu/packages/bootstrap.scm
+++ b/gnu/packages/bootstrap.scm
@@ -197,6 +197,33 @@ successful, or false to signal an error."
                             "guile-2.0.11.tar.xz")
                            (_
                             "guile-2.0.9.tar.xz"))))
+         ;; The following code, run by the bootstrap guile after it is
+         ;; unpacked, creates a wrapper for itself to set its load path.
+         ;; This replaces the previous non-portable method based on
+         ;; reading the /proc/self/exe symlink.
+         (make-guile-wrapper
+          '(begin
+             (use-modules (ice-9 match))
+             (match (command-line)
+               ((_ out bash)
+                (let ((bin-dir    (string-append out "/bin"))
+                      (guile      (string-append out "/bin/guile"))
+                      (guile-real (string-append out "/bin/.guile-real"))
+                      ;; We must avoid using a bare dollar sign in this code,
+                      ;; because it would be interpreted by the shell.
+                      (dollar     (string (integer->char 36))))
+                  (chmod bin-dir #o755)
+                  (rename-file guile guile-real)
+                  (call-with-output-file guile
+                    (lambda (p)
+                      (format p "\
+#!~a
+export GUILE_SYSTEM_PATH=~a/share/guile/2.0
+export GUILE_SYSTEM_COMPILED_PATH=~a/lib/guile/2.0/ccache
+exec -a \"~a0\" ~a \"~a@\"\n"
+                              bash out out dollar guile-real dollar)))
+                  (chmod guile   #o555)
+                  (chmod bin-dir #o555))))))
          (builder
           (add-text-to-store store
                              "build-bootstrap-guile.sh"
@@ -206,10 +233,17 @@ echo \"unpacking bootstrap Guile to '$out'...\"
 cd $out
 ~a -dc < ~a | ~a xv
 
+# Use the bootstrap guile to create its own wrapper to set the load path.
+GUILE_SYSTEM_PATH=$out/share/guile/2.0 \
+GUILE_SYSTEM_COMPILED_PATH=$out/lib/guile/2.0/ccache \
+$out/bin/guile -c ~s $out ~a
+
 # Sanity check.
 $out/bin/guile --version~%"
-                                     mkdir xz guile tar)
-                             (list mkdir xz guile tar))))
+                                     mkdir xz guile tar
+                                     (format #f "~s" make-guile-wrapper)
+                                     bash)
+                             (list mkdir xz guile tar bash))))
     (derivation store name
                 bash `(,builder)
                 #:system system
diff --git a/gnu/packages/commencement.scm b/gnu/packages/commencement.scm
index 02a9a3632c..d3f239f5f7 100644
--- a/gnu/packages/commencement.scm
+++ b/gnu/packages/commencement.scm
@@ -284,6 +284,7 @@
   ;; because we don't need the stand-alone Info reader.
   ;; Also, use %BOOT0-INPUTS to avoid building Perl once more.
   (let ((texinfo (package (inherit texinfo)
+                   (native-inputs '())
                    (inputs (alist-delete "ncurses" (package-inputs texinfo))))))
     (package-with-bootstrap-guile
      (package-with-explicit-inputs texinfo %boot0-inputs
diff --git a/gnu/packages/cross-base.scm b/gnu/packages/cross-base.scm
index b5e07b81f0..712aa9d585 100644
--- a/gnu/packages/cross-base.scm
+++ b/gnu/packages/cross-base.scm
@@ -165,8 +165,7 @@ may be either a libc package or #f.)"
                   ;; Add the cross Linux headers to CROSS_CPATH, and remove them
                   ;; from CPATH.
                   (let ((libc  (assoc-ref inputs "libc"))
-                        (linux (assoc-ref inputs
-                                          "libc/linux-headers")))
+                        (linux (assoc-ref inputs "linux-headers")))
                     (define (cross? x)
                       ;; Return #t if X is a cross-libc or cross Linux.
                       (or (string-prefix? libc x)
@@ -314,7 +313,7 @@ XBINUTILS and the cross tool chain."
               #t))
           ,phases))))
 
-    ;; Shadow the native "linux-headers" because glibc's recipe expect the
+    ;; Shadow the native "linux-headers" because glibc's recipe expects the
     ;; "linux-headers" input to point to the right thing.
     (propagated-inputs `(("linux-headers" ,xlinux-headers)))
 
diff --git a/gnu/packages/ed.scm b/gnu/packages/ed.scm
index 0d2b24cf8d..7cd1fcd71d 100644
--- a/gnu/packages/ed.scm
+++ b/gnu/packages/ed.scm
@@ -27,14 +27,14 @@
 (define-public ed
   (package
     (name "ed")
-    (version "1.11")
+    (version "1.12")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/ed/ed-"
                                  version ".tar.lz"))
              (sha256
               (base32
-               "0d518yhs3kpdpv9fbpa1rhxk2fbry2yzcknrdaa20pi2bzg6w55x"))))
+               "0bw0187a311rci58vznvncsj6pfp8bhs5phrlrqn03sa2i1mfrfj"))))
     (build-system gnu-build-system)
     (native-inputs `(("lzip" ,lzip)))
     (arguments
diff --git a/gnu/packages/emacs.scm b/gnu/packages/emacs.scm
index f00e15c86a..84e167d1fe 100644
--- a/gnu/packages/emacs.scm
+++ b/gnu/packages/emacs.scm
@@ -408,8 +408,7 @@ operations.")
                                          "/bin/emacs"))
                 (magit    (string-append (assoc-ref %build-inputs "magit")
                                          "/share/emacs/site-lisp"))
-                (commit   (string-append (assoc-ref %build-inputs
-                                                    "magit/git-modes")
+                (commit   (string-append (assoc-ref %build-inputs "git-modes")
                                          "/share/emacs/site-lisp"))
                 (source   (assoc-ref %build-inputs "source"))
                 (lisp-dir (string-append %output "/share/emacs/site-lisp")))
diff --git a/gnu/packages/fontutils.scm b/gnu/packages/fontutils.scm
index c04f24b83c..5953caa87a 100644
--- a/gnu/packages/fontutils.scm
+++ b/gnu/packages/fontutils.scm
@@ -40,13 +40,13 @@
 (define-public freetype
   (package
    (name "freetype")
-   (version "2.5.5")
+   (version "2.6")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://savannah/freetype/freetype-"
                                 version ".tar.bz2"))
             (sha256 (base32
-                     "1fdgl7js99xv1yy5zx1ravmqd0jxlnqpv7zcl954h4hbg15wqyrq"))))
+                     "0zilx15fwcpa8hmcxpc423jwb8ijw4qpq968kh18akvn4j0znsc4"))))
    (build-system gnu-build-system)
    (arguments
     `(#:phases
diff --git a/gnu/packages/gcc.scm b/gnu/packages/gcc.scm
index d2fe122f62..6aa0942674 100644
--- a/gnu/packages/gcc.scm
+++ b/gnu/packages/gcc.scm
@@ -59,9 +59,7 @@ where the OS part is overloaded to denote a specific ABI---into GCC
          '("--with-arch=armv7-a"
            "--with-float=hard"
            "--with-mode=thumb"
-
-           ;; See <https://wiki.debian.org/ArmHardFloatPort/VfpComparison#FPU>
-           "--with-fpu=vfpv3-d16"))
+           "--with-fpu=neon"))
 
         (else
          ;; TODO: Add `arm.*-gnueabi', etc.
@@ -323,17 +321,15 @@ Go.  It also includes runtime support libraries for these languages.")
 
 (define-public gcc-4.9
   (package (inherit gcc-4.8)
-    (version "4.9.2")
+    (version "4.9.3")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnu/gcc/gcc-"
                                   version "/gcc-" version ".tar.bz2"))
               (sha256
                (base32
-                "1pbjp4blk2ycaa6r3jmw4ky5f1s9ji3klbqgv8zs2sl5jn1cj810"))
-              (patches (map search-patch
-                            '("gcc-arm-link-spec-fix.patch"
-                              "gcc-libvtv-runpath.patch")))))))
+                "0zmnm00d2a1hsd41g34bhvxzvxisa2l584q3p447bd91lfjv4ci3"))
+              (patches (list (search-patch "gcc-libvtv-runpath.patch")))))))
 
 (define-public gcc-5.1
   (package (inherit gcc-4.9)
diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index 9289946178..6be3093bd6 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -35,15 +35,14 @@
 (define-public gnu-gettext
   (package
     (name "gettext")
-    (version "0.19.4")
+    (version "0.19.5")
     (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/gettext/gettext-"
                                  version ".tar.gz"))
              (sha256
               (base32
-               "0gvz86m4cs8bdf3mwmwsyx6lrq4ydfxgadrgd9jlx32z3bnz3jca"))
-             (patches (list (search-patch "gettext-msgunfmt.patch")))))
+               "0fppvj4l9maa9q1swvhnv96hsqxx90vcjbdyjhqpir3ll55q2n0j"))))
     (build-system gnu-build-system)
     (inputs
      `(("expat" ,expat)))
diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 879c27e86a..2cb44f97ba 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -1086,8 +1086,8 @@ to access local and remote files with a single consistent API.")
           (substitute* "libgnome/Makefile.in"
             (("-DG_DISABLE_DEPRECATED") "-DGLIB_DISABLE_DEPRECATION_WARNINGS")))
         %standard-phases)))
-    (inputs `(("popt" ,popt)
-              ("libxml2" ,libxml2)))
+    (propagated-inputs `(("popt" ,popt)))  ; gnome-program.h includes popt.h
+    (inputs `(("libxml2" ,libxml2)))
     (native-inputs
      `(("glib" ,glib "bin")             ; for glib-mkenums, etc.
        ("intltool" ,intltool)
diff --git a/gnu/packages/gnupg.scm b/gnu/packages/gnupg.scm
index 8aea3dabb9..1c2b567d89 100644
--- a/gnu/packages/gnupg.scm
+++ b/gnu/packages/gnupg.scm
@@ -41,7 +41,7 @@
 (define-public libgpg-error
   (package
     (name "libgpg-error")
-    (version "1.18")
+    (version "1.19")
     (source
      (origin
       (method url-fetch)
@@ -49,7 +49,7 @@
                           version ".tar.bz2"))
       (sha256
        (base32
-        "0408v19h3h0q6w61g51hgbdg6cyw81nyzkh70qfprvsc3pkddwcz"))))
+        "12wpqhjlsw4iaanifbqm2kich6c7x7lm8a7zhy6x5ifm6c9hw4jk"))))
     (build-system gnu-build-system)
     (home-page "http://gnupg.org")
     (synopsis "Library of error values for GnuPG components")
diff --git a/gnu/packages/libidn.scm b/gnu/packages/libidn.scm
index 49dafbeb6d..4a7840c78c 100644
--- a/gnu/packages/libidn.scm
+++ b/gnu/packages/libidn.scm
@@ -26,13 +26,13 @@
 (define-public libidn
   (package
    (name "libidn")
-   (version "1.30")
+   (version "1.31")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/libidn/libidn-" version
                                 ".tar.gz"))
             (sha256 (base32
-                     "0lxh5r1z8gsk4jxx3rv8aasjv8p53j4y04kvfn2w30a0syagrf9r"))))
+                     "026z12mczlag443ms9n954h36pi3m7iva9jfw8y4ispsj772zpxg"))))
    (build-system gnu-build-system)
 ;; FIXME: No Java and C# libraries are currently built.
    (synopsis "Internationalized string processing library")
diff --git a/gnu/packages/libunistring.scm b/gnu/packages/libunistring.scm
index aa053711a9..f29b7424de 100644
--- a/gnu/packages/libunistring.scm
+++ b/gnu/packages/libunistring.scm
@@ -26,7 +26,7 @@
 (define-public libunistring
   (package
    (name "libunistring")
-   (version "0.9.5")
+   (version "0.9.6")
    (source (origin
             (method url-fetch)
             (uri (string-append
@@ -34,7 +34,7 @@
                   version ".tar.gz"))
             (sha256
              (base32
-              "05va4x47ik006nd13grwm276gfxb8igsj63k37vvwl3q8rr0g30s"))))
+              "0ixxmgpgh2v8ifm6hbwsjxl023myk3dfnj7wnvmqjivza31fw9cn"))))
    (propagated-inputs '())                  ; FIXME: add libiconv when !glibc
    (build-system gnu-build-system)
    (arguments
diff --git a/gnu/packages/make-bootstrap.scm b/gnu/packages/make-bootstrap.scm
index e140582a4a..07e8b5160b 100644
--- a/gnu/packages/make-bootstrap.scm
+++ b/gnu/packages/make-bootstrap.scm
@@ -629,7 +629,9 @@ for `sh' in $PATH, and without nscd, and with static NSS modules."
                                               ,(or (%current-target-system)
                                                    (%current-system))
                                               ".tar.xz")
-                               "."))))))))))
+                               "."
+                               ;; avoid non-determinism in the archive
+                               "--mtime=@0" "--owner=root:0" "--group=root:0"))))))))))
 
 (define %bootstrap-binaries-tarball
   ;; A tarball with the statically-linked bootstrap binaries.
diff --git a/gnu/packages/multiprecision.scm b/gnu/packages/multiprecision.scm
index da52b2b1e9..903d160b24 100644
--- a/gnu/packages/multiprecision.scm
+++ b/gnu/packages/multiprecision.scm
@@ -47,15 +47,7 @@
                 '(;; Build a "fat binary", with routines for several
                   ;; sub-architectures.
                   "--enable-fat"
-                  "--enable-cxx"
-
-                  ;; FIXME: gmp-6.0.0a's config.guess fails on
-                  ;; multi-core armhf systems.
-                  ,@(if (%current-target-system)
-                        '()
-                        (let ((triplet
-                               (nix-system->gnu-triplet (%current-system))))
-                          (list (string-append "--build=" triplet)))))))
+                  "--enable-cxx")))
    (synopsis "Multiple-precision arithmetic library")
    (description
     "GMP is a library for arbitrary precision arithmetic, operating on
@@ -69,13 +61,13 @@ cryptography and computational algebra.")
 (define-public mpfr
   (package
    (name "mpfr")
-   (version "3.1.2")
+   (version "3.1.3")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/mpfr/mpfr-" version
                                 ".tar.xz"))
             (sha256 (base32
-                     "0fs501qi8l523gs3cpy4jjcnvwxggyfbklcys80wq236xx3hz79r"))))
+                     "05jaa5z78lvrayld09nyr0v27c1m5dm9l7kr85v2bj4jv65s0db8"))))
    (build-system gnu-build-system)
    (outputs '("out" "debug"))
    (propagated-inputs `(("gmp" ,gmp)))            ; <mpfr.h> refers to <gmp.h>
diff --git a/gnu/packages/patches/coreutils-dummy-man.patch b/gnu/packages/patches/coreutils-dummy-man.patch
deleted file mode 100644
index a43cfc47c3..0000000000
--- a/gnu/packages/patches/coreutils-dummy-man.patch
+++ /dev/null
@@ -1,21 +0,0 @@
-Patch adapted from <http://git.yoctoproject.org/cgit.cgi/poky/plain/meta/recipes-core/coreutils/coreutils-8.22/fix-for-dummy-man-usage.patch>.
-
-Fix for 'dummy-man' usage, when cross-compiling.
-
-The options should be before the final argument, otherwise, the following error
-would appear when compiling:
-
-  dummy-man: too many non-option arguments
-
---- coreutils-8.23/Makefile.in	2014-07-18 18:22:24.000000000 -0400
-+++ coreutils-8.23/Makefile.in	2014-08-03 20:21:10.849158313 -0400
-@@ -14076,8 +14076,8 @@
- 	  && $(run_help2man)						\
- 		     --source='$(PACKAGE_STRING)'			\
- 		     --include=$(srcdir)/man/$$name.x			\
--		     --output=$$t/$$name.1 $$t/$$argv			\
- 		     --info-page='coreutils \(aq'$$name' invocation\(aq' \
-+		     --output=$$t/$$name.1 $$t/$$argv			\
- 	  && sed \
- 	       -e 's|$*\.td/||g' \
- 	       -e '/For complete documentation/d' \
diff --git a/gnu/packages/patches/gettext-msgunfmt.patch b/gnu/packages/patches/gettext-msgunfmt.patch
deleted file mode 100644
index 4a50abddc2..0000000000
--- a/gnu/packages/patches/gettext-msgunfmt.patch
+++ /dev/null
@@ -1,58 +0,0 @@
-From <http://git.savannah.gnu.org/cgit/gettext.git/patch/?id=5d3eeaa0d3b7f4f6932bd29d859925a940b69459>.
-
-2015-03-11  Daiki Ueno  <ueno@gnu.org>
-
-	msgunfmt: Check allocated size for static segment
-	Reported by Max Lin in:
-	http://lists.gnu.org/archive/html/bug-gettext/2015-03/msg00005.html
-	* read-mo.c (get_sysdep_string): Check if the embedded segment
-	size is valid, before adding it to the string length.
-
-diff --git a/gettext-tools/src/read-mo.c b/gettext-tools/src/read-mo.c
-index b97bbad..1c024a8 100644
---- a/gettext-tools/src/read-mo.c
-+++ b/gettext-tools/src/read-mo.c
-@@ -149,6 +149,7 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
-   nls_uint32 s_offset;
- 
-   /* Compute the length.  */
-+  s_offset = get_uint32 (bfp, offset);
-   length = 0;
-   for (i = 4; ; i += 8)
-     {
-@@ -158,9 +159,14 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
-       nls_uint32 ss_length;
-       nls_uint32 ss_offset;
-       size_t ss_end;
-+      size_t s_end;
-       size_t n;
- 
-+      s_end = xsum (s_offset, segsize);
-+      if (size_overflow_p (s_end) || s_end > bfp->size)
-+        error (EXIT_FAILURE, 0, _("file \"%s\" is truncated"), bfp->filename);
-       length += segsize;
-+      s_offset += segsize;
- 
-       if (sysdepref == SEGMENTS_END)
-         break;
-@@ -175,7 +181,7 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
-       ss_end = xsum (ss_offset, ss_length);
-       if (size_overflow_p (ss_end) || ss_end > bfp->size)
-         error (EXIT_FAILURE, 0, _("file \"%s\" is truncated"), bfp->filename);
--      if (!(ss_length > 0 && bfp->data[ss_offset + ss_length - 1] == '\0'))
-+      if (!(ss_length > 0 && bfp->data[ss_end - 1] == '\0'))
-         {
-           char location[30];
-           sprintf (location, "sysdep_segment[%u]", (unsigned int) sysdepref);
-@@ -198,11 +204,8 @@ get_sysdep_string (const struct binary_mo_file *bfp, size_t offset,
-       nls_uint32 sysdep_segment_offset;
-       nls_uint32 ss_length;
-       nls_uint32 ss_offset;
--      size_t s_end = xsum (s_offset, segsize);
-       size_t n;
- 
--      if (size_overflow_p (s_end) || s_end > bfp->size)
--        error (EXIT_FAILURE, 0, _("file \"%s\" is truncated"), bfp->filename);
-       memcpy (p, bfp->data + s_offset, segsize);
-       p += segsize;
-       s_offset += segsize;
diff --git a/gnu/packages/pcre.scm b/gnu/packages/pcre.scm
index 86d3ca3874..d07e434190 100644
--- a/gnu/packages/pcre.scm
+++ b/gnu/packages/pcre.scm
@@ -45,6 +45,9 @@
                           "--enable-pcregrep-libz"
                           "--enable-pcregrep-libbz2"
                           "--enable-pcretest-libreadline"
+                          "--enable-unicode-properties"
+                          "--enable-pcre16"
+                          "--enable-pcre32"
                           "--enable-jit")))
    (synopsis "Perl Compatible Regular Expressions")
    (description
diff --git a/gnu/packages/perl.scm b/gnu/packages/perl.scm
index 3d28455405..d1a0218158 100644
--- a/gnu/packages/perl.scm
+++ b/gnu/packages/perl.scm
@@ -72,7 +72,15 @@
                         "-Dinstallstyle=lib/perl5"
                         "-Duseshrplib"
                         (string-append "-Dlocincpth=" libc "/include")
-                        (string-append "-Dloclibpth=" libc "/lib"))))))
+                        (string-append "-Dloclibpth=" libc "/lib")
+
+                        ;; Force the library search path to contain only libc
+                        ;; because it is recorded in Config.pm and
+                        ;; Config_heavy.pl; we don't want to keep a reference
+                        ;; to everything that's in $LIBRARY_PATH at build
+                        ;; time (Binutils, bzip2, file, etc.)
+                        (string-append "-Dlibpth=" libc "/lib")
+                        (string-append "-Dplibpth=" libc "/lib"))))))
 
          (add-before
           'strip 'make-shared-objects-writable
diff --git a/gnu/packages/python.scm b/gnu/packages/python.scm
index 5dcaba0871..9ceb5b2f5e 100644
--- a/gnu/packages/python.scm
+++ b/gnu/packages/python.scm
@@ -155,24 +155,40 @@
                 "-L" zlib "/lib "
                 "-Wl,-rpath=" out "/lib")))
 
+        #:modules ((ice-9 ftw)
+                   ,@%gnu-build-system-modules)
         #:phases
-        (alist-cons-before
-         'configure 'patch-lib-shells
-         (lambda _
-           ;; Filter for existing files, since some may not exist in all
-           ;; versions of python that are built with this recipe.
-           (substitute* (filter file-exists?
-                                '("Lib/subprocess.py"
-                                  "Lib/popen2.py"
-                                  "Lib/distutils/tests/test_spawn.py"
-                                  "Lib/test/test_subprocess.py"))
-             (("/bin/sh") (which "sh"))))
-         (alist-cons-before
-          'check 'pre-check
-          (lambda _
-            ;; 'Lib/test/test_site.py' needs a valid $HOME
-            (setenv "HOME" (getcwd)))
-          %standard-phases))))
+        (modify-phases %standard-phases
+          (add-before
+           'configure 'patch-lib-shells
+           (lambda _
+             ;; Filter for existing files, since some may not exist in all
+             ;; versions of python that are built with this recipe.
+             (substitute* (filter file-exists?
+                                  '("Lib/subprocess.py"
+                                    "Lib/popen2.py"
+                                    "Lib/distutils/tests/test_spawn.py"
+                                    "Lib/test/test_subprocess.py"))
+               (("/bin/sh") (which "sh")))
+             #t))
+          (add-before
+           'check 'pre-check
+           (lambda _
+             ;; 'Lib/test/test_site.py' needs a valid $HOME
+             (setenv "HOME" (getcwd))
+             #t))
+          (add-after
+           'unpack 'set-source-file-times-to-1980
+           ;; XXX One of the tests uses a ZIP library to pack up some of the
+           ;; source tree, and fails with "ZIP does not support timestamps
+           ;; before 1980".  Work around this by setting the file times in the
+           ;; source tree to sometime in early 1980.
+           (lambda _
+             (let ((circa-1980 (* 10 366 24 60 60)))
+               (ftw "." (lambda (file stat flag)
+                          (utime file circa-1980 circa-1980)
+                          #t))
+               #t))))))
     (inputs
      `(("bzip2" ,bzip2)
        ("gdbm" ,gdbm)
diff --git a/gnu/packages/qt.scm b/gnu/packages/qt.scm
index 340462dba3..313d63993a 100644
--- a/gnu/packages/qt.scm
+++ b/gnu/packages/qt.scm
@@ -297,8 +297,7 @@ developers using C++ or QML, a CSS & JavaScript like language.")
                       "-no-ssse3"
                       "-no-sse4.1"
                       "-no-sse4.2"
-                      "-no-avx"
-                      "-no-neon")))))
+                      "-no-avx")))))
          (add-after
           'install 'move-doc
           (lambda* (#:key outputs #:allow-other-keys)
diff --git a/gnu/packages/ssh.scm b/gnu/packages/ssh.scm
index bf2e8896d6..a827aa1d90 100644
--- a/gnu/packages/ssh.scm
+++ b/gnu/packages/ssh.scm
@@ -262,7 +262,7 @@ libssh library.")
      '(#:phases
        (alist-replace
         'configure
-        (lambda* (#:key outputs inputs system target
+        (lambda* (#:key outputs inputs system build target
                         #:allow-other-keys #:rest args)
           (let* ((configure (assoc-ref %standard-phases 'configure))
                  (prefix (assoc-ref outputs "out"))
@@ -270,9 +270,8 @@ libssh library.")
                  ;; Set --build and --host flags as the provided config.guess
                  ;; is not able to detect them
                  (flags `(,(string-append "--prefix=" prefix)
-                          ,(string-append "--build=" system)
-                          ,(string-append "--host="
-                                          (or target system)))))
+                          ,(string-append "--build=" build)
+                          ,(string-append "--host=" (or target build)))))
             (setenv "CONFIG_SHELL" bash)
             (zero? (apply system* bash
                           (string-append "." "/configure")
diff --git a/gnu/packages/texinfo.scm b/gnu/packages/texinfo.scm
index ca411a95ac..92bd9471dd 100644
--- a/gnu/packages/texinfo.scm
+++ b/gnu/packages/texinfo.scm
@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2012, 2013, 2015 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
+;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -25,20 +26,22 @@
   #:use-module (gnu packages)
   #:use-module (gnu packages compression)
   #:use-module (gnu packages perl)
+  #:use-module (gnu packages linux)
   #:use-module (gnu packages ncurses))
 
 (define-public texinfo
   (package
     (name "texinfo")
-    (version "5.2")
+    (version "6.0")
     (source (origin
-             (method url-fetch)
-             (uri (string-append "mirror://gnu/texinfo/texinfo-"
-                                 version ".tar.xz"))
-             (sha256
-              (base32
-               "1njfwh2z34r2c4r0iqa7v24wmjzvsfyz4vplzry8ln3479lfywal"))))
+              (method url-fetch)
+              (uri (string-append "mirror://gnu/texinfo/texinfo-"
+                                  version ".tar.xz"))
+              (sha256
+               (base32
+                "1r3i6jyynn6ab45fxw5bms8mflk9ry4qpj6gqyry72vfd5c47fhi"))))
     (build-system gnu-build-system)
+    (native-inputs `(("procps" ,procps)))  ;one of the tests needs pgrep
     (inputs `(("ncurses" ,ncurses)
               ("xz" ,xz)
               ("perl" ,perl)))
@@ -53,17 +56,17 @@ their source and the command-line Info reader.  The emphasis of the language
 is on expressing the content semantically, avoiding physical markup commands.")
     (license gpl3+)))
 
-(define-public texinfo-6
-  (package
-    (inherit texinfo)
-    (version "6.0")
+(define-public texinfo-5
+  (package (inherit texinfo)
+    (version "5.2")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnu/texinfo/texinfo-"
                                   version ".tar.xz"))
               (sha256
                (base32
-                "1r3i6jyynn6ab45fxw5bms8mflk9ry4qpj6gqyry72vfd5c47fhi"))))))
+                "1njfwh2z34r2c4r0iqa7v24wmjzvsfyz4vplzry8ln3479lfywal"))))
+    (native-inputs '())))
 
 (define-public texinfo-4
   (package (inherit texinfo)
@@ -77,6 +80,7 @@ is on expressing the content semantically, avoiding physical markup commands.")
               (sha256
                (base32
                 "1rf9ckpqwixj65bw469i634897xwlgkm5i9g2hv3avl6mv7b0a3d"))))
+    (native-inputs '())
     (inputs `(("ncurses" ,ncurses) ("xz" ,xz)))))
 
 (define-public texi2html
diff --git a/gnu/packages/video.scm b/gnu/packages/video.scm
index d0983808c6..9a0e959d54 100644
--- a/gnu/packages/video.scm
+++ b/gnu/packages/video.scm
@@ -139,14 +139,7 @@ old-fashioned output methods with powerful ascii-art renderer.")
      `(("autoconf" ,autoconf)
        ("automake" ,automake)
        ("libtool" ,libtool)))
-    (arguments `(#:configure-flags
-                 '("--enable-shared"
-                   ;; FIXME: liba52-0.7.4's config.guess fails on mips64el.
-                   ,@(if (%current-target-system)
-                         '()
-                         (let ((triplet
-                                (nix-system->gnu-triplet (%current-system))))
-                           (list (string-append "--build=" triplet)))))
+    (arguments `(#:configure-flags '("--enable-shared")
                  #:phases
                  (modify-phases %standard-phases
                    ;; XXX We need to run ./bootstrap because of the build
@@ -665,7 +658,6 @@ treaming protocols.")
                                     (or (%current-target-system)
                                         (nix-system->gnu-triplet
                                          (%current-system)))))))
-                      "--disable-neon"
                       "--disable-iwmmxt"))))
           %standard-phases)))
     (home-page "http://www.mplayerhq.hu/design7/news.html")
@@ -905,23 +897,6 @@ projects while introducing many more.")
                      (zero? (system* "./configure"
                                      "--enable-shared"
                                      "--as=yasm"
-                                     ,@(if (and (not (%current-target-system))
-                                                (string-prefix?
-                                                 "armhf-"
-                                                 (%current-system)))
-                                           ;; When building on ARMv7, libvpx
-                                           ;; assumes that NEON will be
-                                           ;; available.  On Guix, armhf
-                                           ;; does not require NEON, so we
-                                           ;; build for ARMv6 and -marm (since
-                                           ;; no thumb2 on ARMv6) to ensure
-                                           ;; compatibility with all ARMv7
-                                           ;; cores we support.  Based on
-                                           ;; the Debian libvpx package.
-                                           '("--target=armv6-linux-gcc"
-                                             "--extra-cflags=-marm"
-                                             "--enable-small")
-                                           '())
                                      (string-append "--prefix=" out)))))
                  %standard-phases)
        #:tests? #f)) ; no check target
@@ -1157,7 +1132,9 @@ for use with HTML5 video.")
            (with-directory-excursion "avidemux_core/ffmpeg_package"
              (substitute* "ffmpeg-1.2.1/configure"
                (("#! /bin/sh") (string-append "#!" (which "bash"))))
-             (system* "tar" "cjf" "ffmpeg-1.2.1.tar.bz2" "ffmpeg-1.2.1")
+             (system* "tar" "cjf" "ffmpeg-1.2.1.tar.bz2" "ffmpeg-1.2.1"
+                      ;; avoid non-determinism in the archive
+                      "--mtime=@0" "--owner=root:0" "--group=root:0")
              (delete-file-recursively "ffmpeg-1.2.1")))
          (alist-replace 'configure
           (lambda _
diff --git a/gnu/packages/xdisorg.scm b/gnu/packages/xdisorg.scm
index f928aa1f58..2f6738f1eb 100644
--- a/gnu/packages/xdisorg.scm
+++ b/gnu/packages/xdisorg.scm
@@ -447,13 +447,6 @@ transparent text on your screen.")
     (inputs
      `(("libx11" ,libx11)
        ("guile" ,guile-2.0)))
-    (arguments `(#:configure-flags
-                 '(;; FIXME: xbindkeys-1.8.6's config.guess fails on mips64el.
-                   ,@(if (%current-target-system)
-                         '()
-                         (let ((triplet
-                                (nix-system->gnu-triplet (%current-system))))
-                           (list (string-append "--build=" triplet)))))))
     (home-page "http://www.nongnu.org/xbindkeys/")
     (synopsis "Associate a combination of keys with a shell command")
     (description
diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index 5763439ba3..03f933c2df 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -417,17 +417,26 @@ providing the system administrator with some help in common tasks.")
                                (string-append "--with-bashcompletiondir="
                                               (assoc-ref %outputs "out")
                                               "/etc/bash_completion.d"))
-       #:phases (alist-cons-before
-                 'check 'pre-check
-                 (lambda* (#:key inputs outputs #:allow-other-keys)
-                   (let ((out (assoc-ref outputs "out"))
-                         (net (assoc-ref inputs "net-base")))
-                     ;; Change the test to refer to the right file.
-                     (substitute* "tests/ts/misc/mcookie"
-                       (("/etc/services")
-                        (string-append net "/etc/services")))
-                     #t))
-                 %standard-phases)))
+       #:phases (modify-phases %standard-phases
+                  (add-before
+                   'build 'set-umount-file-name
+                   (lambda* (#:key outputs #:allow-other-keys)
+                     ;; Tell 'eject' the right file name of 'umount'.
+                     (let ((out (assoc-ref outputs "out")))
+                       (substitute* "sys-utils/eject.c"
+                         (("\"/bin/umount\"")
+                          (string-append "\"" out "/bin/umount\"")))
+                       #t)))
+                  (add-before
+                   'check 'pre-check
+                   (lambda* (#:key inputs outputs #:allow-other-keys)
+                     (let ((out (assoc-ref outputs "out"))
+                           (net (assoc-ref inputs "net-base")))
+                       ;; Change the test to refer to the right file.
+                       (substitute* "tests/ts/misc/mcookie"
+                         (("/etc/services")
+                          (string-append net "/etc/services")))
+                       #t))))))
     (inputs `(("zlib" ,zlib)
               ("ncurses" ,ncurses)))
     (native-inputs
@@ -2014,13 +2023,6 @@ also contains the libsysfs library.")
            (substitute* "configure"
              (("includedir='(\\$\\{prefix\\}/include)'" all orig)
               (string-append "includedir='" orig "/sysfs'")))))))
-    ;; XXX sysfsutils-1.3.0's config.guess fails on mips64el
-    (arguments `(#:configure-flags
-                 '(,@(if (%current-target-system)
-                         '()
-                         (let ((triplet
-                                (nix-system->gnu-triplet (%current-system))))
-                           (list (string-append "--build=" triplet)))))))
     (synopsis "System utilities based on Linux sysfs (version 1.x)")))
 
 (define-public cpufrequtils